@@ -631,6 +631,12 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       InheritException(exception,&image->exception);
       return(DestroyImageList(image));
     }
+  status=ResetImagePixels(image,exception);
+  if (status == MagickFalse)
+    { 
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }     
   if (image->storage_class == PseudoClass)
     {
       size_t
