@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -294,6 +294,8 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       image_info->filename);
   image=AcquireImage(image_info);
+  image->columns=0;
+  image->rows=0;
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -345,7 +347,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
         p=value;
         if (*p == '=')
           {
-            p+=2;
+            p+=(ptrdiff_t) 2;
             while (isspace((int) ((unsigned char) *p)) != 0)
               p++;
           }
@@ -429,7 +431,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     if (EOFBlob(image) != MagickFalse)
       ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
         image->filename);
-    number_pixels=(MagickSizeType) fits_info.columns*fits_info.rows;
+    number_pixels=(MagickSizeType) (fits_info.columns*fits_info.rows);
     if ((fits_info.simple == MagickFalse) || (fits_info.number_axes < 1) ||
         (fits_info.number_axes > 4) || (number_pixels == 0) ||
         (fits_info.number_planes <= 0))
@@ -470,8 +472,8 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
       /*
         Convert FITS pixels to pixel packets.
       */
-      scale=QuantumRange*PerceptibleReciprocal(fits_info.max_data-
-        fits_info.min_data);
+      scale=(MagickRealType) QuantumRange*
+        MagickSafeReciprocal(fits_info.max_data-fits_info.min_data);
       for (y=(ssize_t) image->rows-1; y >= 0; y--)
       {
         q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
@@ -562,7 +564,8 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     if (status == MagickFalse)
       break;
   } while (1);
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
   if (status == MagickFalse)
     return(DestroyImageList(image));
   return(GetFirstImageInList(image));
@@ -909,6 +912,7 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
       break;
   } while (image_info->adjoin != MagickFalse);
   fits_info=DestroyString(fits_info);
-  (void) CloseBlob(image);
-  return(MagickTrue);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
+  return(status);
 }
