@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.  You may
@@ -109,7 +109,7 @@ static inline MagickBooleanType InvokeGhostscriptDelegate(
     argc,
     code;
 
-  register ssize_t
+  ssize_t
     i;
 
 #if defined(MAGICKCORE_WINDOWS_SUPPORT)
@@ -226,7 +226,7 @@ static inline void ReadGhostScriptXMPProfile(MagickByteBuffer *buffer,
     found_end,
     status;
 
-  register char
+  char
     *p;
 
   size_t
@@ -235,11 +235,11 @@ static inline void ReadGhostScriptXMPProfile(MagickByteBuffer *buffer,
   ssize_t
     count;
 
-  if (*profile != (StringInfo *) NULL)
-    return;
   status=CompareMagickByteBuffer(buffer,BeginXMPPacket,strlen(BeginXMPPacket));
   if (status == MagickFalse)
     return;
+  if (*profile != (StringInfo *) NULL)
+    *profile=DestroyStringInfo(*profile);
   length=8192;
   *profile=AcquireStringInfo(length);
   found_end=MagickFalse;
