@@ -207,12 +207,14 @@ static void InsertComplexDoubleRow(double *p,int y,Image *image,double MinVal,
   {
     if (*p > 0)
       {
-        f=(*p/MaxVal)*(Quantum) (QuantumRange-GetPixelRed(q));
-        if ((f+GetPixelRed(q)) >= QuantumRange)
+        f=(*p/MaxVal)*((MagickRealType) QuantumRange-(MagickRealType)
+          GetPixelRed(q));
+        if ((f+(MagickRealType) GetPixelRed(q)) >= (MagickRealType) QuantumRange)
           SetPixelRed(q,QuantumRange);
         else
-          SetPixelRed(q,GetPixelRed(q)+ClampToQuantum(f));
-        f=GetPixelGreen(q)-f/2.0;
+          SetPixelRed(q,(MagickRealType) GetPixelRed(q)+(MagickRealType)
+            ClampToQuantum(f));
+        f=(MagickRealType) GetPixelGreen(q)-f/2.0;
         if (f <= 0.0)
           {
             SetPixelGreen(q,0);
@@ -226,12 +228,14 @@ static void InsertComplexDoubleRow(double *p,int y,Image *image,double MinVal,
       }
     if (*p < 0)
       {
-        f=(*p/MinVal)*(Quantum) (QuantumRange-GetPixelBlue(q));
-        if ((f+GetPixelBlue(q)) >= QuantumRange)
+        f=(*p/MinVal)*((MagickRealType) QuantumRange-(MagickRealType)
+          GetPixelBlue(q));
+        if ((f+(MagickRealType) GetPixelBlue(q)) >= (MagickRealType) QuantumRange)
           SetPixelBlue(q,QuantumRange);
         else
-          SetPixelBlue(q,GetPixelBlue(q)+ClampToQuantum(f));
-        f=GetPixelGreen(q)-f/2.0;
+          SetPixelBlue(q,(MagickRealType) GetPixelBlue(q)+(MagickRealType)
+            ClampToQuantum(f));
+        f=(MagickRealType) GetPixelGreen(q)-f/2.0;
         if (f <= 0.0)
           {
             SetPixelRed(q,0);
@@ -275,13 +279,14 @@ static void InsertComplexFloatRow(float *p,int y,Image *image,double MinVal,
   {
     if (*p > 0)
       {
-        f=(*p/MaxVal)*(Quantum) (QuantumRange-GetPixelRed(q));
-        if ((f+GetPixelRed(q)) < QuantumRange)
+        f=((MagickRealType) *p/MaxVal)*((MagickRealType) QuantumRange-
+          (MagickRealType) GetPixelRed(q));
+        if ((f+(MagickRealType) GetPixelRed(q)) < (MagickRealType) QuantumRange)
           SetPixelRed(q,GetPixelRed(q)+ClampToQuantum(f));
         else
           SetPixelRed(q,QuantumRange);
         f/=2.0;
-        if (f < GetPixelGreen(q))
+        if (f < (MagickRealType) GetPixelGreen(q))
           {
             SetPixelBlue(q,GetPixelBlue(q)-ClampToQuantum(f));
             SetPixelGreen(q,GetPixelBlue(q));
@@ -294,13 +299,14 @@ static void InsertComplexFloatRow(float *p,int y,Image *image,double MinVal,
       }
     if (*p < 0)
       {
-        f=(*p/MaxVal)*(Quantum) (QuantumRange-GetPixelBlue(q));
-        if ((f+GetPixelBlue(q)) < QuantumRange)
+        f=((MagickRealType) *p/MaxVal)*((MagickRealType) QuantumRange-
+          (MagickRealType) GetPixelBlue(q));
+        if ((f+(MagickRealType) GetPixelBlue(q)) < (MagickRealType) QuantumRange)
           SetPixelBlue(q,GetPixelBlue(q)+ClampToQuantum(f));
         else
           SetPixelBlue(q,QuantumRange);
         f/=2.0;
-        if (f < GetPixelGreen(q))
+        if (f < (MagickRealType) GetPixelGreen(q))
           {
             SetPixelRed(q,GetPixelRed(q)-ClampToQuantum(f));
             SetPixelGreen(q,GetPixelRed(q));
@@ -419,9 +425,9 @@ float *fltrow;
       }
     for (x = 0; x < (ssize_t) SizeX; x++)
       {
-        if (*Min > *fltrow)
+        if (*Min > (MagickRealType) *fltrow)
           *Min = *fltrow;
-        if (*Max < *fltrow)
+        if (*Max < (MagickRealType) *fltrow)
           *Max = *fltrow;
         fltrow++;
       }
@@ -571,7 +577,7 @@ ssize_t TotalSize = 0;
       zip_status = inflate(&zip_info,Z_NO_FLUSH);
 			if ((zip_status != Z_OK) && (zip_status != Z_STREAM_END))
         break;
-      extent=fwrite(decompress_block, 4096-zip_info.avail_out, 1, mat_file);
+      extent=fwrite(decompress_block, 1, 4096-zip_info.avail_out, mat_file);
       (void) extent;
       TotalSize += 4096-zip_info.avail_out;
 
@@ -592,6 +598,8 @@ DblBreak:
 
   if((clone_info->file=fopen(clone_info->filename,"rb"))==NULL) goto UnlinkFile;
   if( (image2 = AcquireImage(clone_info))==NULL ) goto EraseFile;
+  image2->columns=0;
+  image2->rows=0;
   status = OpenBlob(clone_info,image2,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
   {
@@ -845,7 +853,8 @@ skip_reading_current:
     if (status == MagickFalse)
       break;
   }
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
   if (status == MagickFalse)
     return(DestroyImageList(image));
   return(GetFirstImageInList(image));
@@ -1637,7 +1646,7 @@ static MagickBooleanType WriteMATImage(const ImageInfo *image_info,Image *image)
   image->depth=8;
 
   current_time=GetMagickTime();
-  GetMagickUTCtime(&current_time,&utc_time);
+  GetMagickUTCTime(&current_time,&utc_time);
   (void) memset(MATLAB_HDR,' ',MagickMin(sizeof(MATLAB_HDR),124));
   FormatLocaleString(MATLAB_HDR,sizeof(MATLAB_HDR),
     "MATLAB 5.0 MAT-file, Platform: %s, Created on: %s %s %2d %2d:%2d:%2d %d",
@@ -1752,6 +1761,7 @@ static MagickBooleanType WriteMATImage(const ImageInfo *image_info,Image *image)
     if (status == MagickFalse)
       break;
   } while (image_info->adjoin != MagickFalse);
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
   return(status);
 }
