@@ -1544,6 +1544,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
     index;
 
   MagickBooleanType
+    added_newline,
     status;
 
   MagickOffsetType
@@ -1762,6 +1763,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         (void) SetImageType(image,BilevelType);
         extent=1;
         q=pixels;
+        added_newline=MagickFalse;
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           const PixelPacket
@@ -1784,12 +1786,19 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                     *q++='\n';
                     (void) WriteBlob(image,(size_t) (q-pixels),pixels);
                     q=pixels;
+                    added_newline=MagickTrue;
                   }
               }
             *q++=(unsigned char) (GetPixelLuma(image,p) >= ((MagickRealType)
               QuantumRange/2.0) ? '0' : '1');
             p++;
           }
+          if (added_newline == MagickFalse)
+            {
+              *q++='\n';
+              (void) WriteBlob(image,(size_t) (q-pixels),pixels);
+              q=pixels;
+            }
           if (image->previous == (Image *) NULL)
             {
               status=SetImageProgress(image,SaveImageTag,(MagickOffsetType) y,
@@ -1821,6 +1830,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           else
             (void) WriteBlobString(image,"4294967295\n");
         q=pixels;
+        added_newline=MagickFalse;
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           const PixelPacket
@@ -1855,12 +1865,19 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                     *q++='\n';
                     (void) WriteBlob(image,(size_t) (q-pixels),pixels);
                     q=pixels;
+                    added_newline=MagickTrue;
                   }
               }
             (void) memcpy((char *) q,buffer,extent);
             q+=(ptrdiff_t) extent;
             p++;
           }
+          if (added_newline == MagickFalse)
+            {
+              *q++='\n';
+              (void) WriteBlob(image,(size_t) (q-pixels),pixels);
+              q=pixels;
+            }
           if (image->previous == (Image *) NULL)
             {
               status=SetImageProgress(image,SaveImageTag,(MagickOffsetType) y,
@@ -1894,6 +1911,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           else
             (void) WriteBlobString(image,"4294967295\n");
         q=pixels;
+        added_newline=MagickFalse;
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           const PixelPacket
@@ -1933,12 +1951,19 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                     *q++='\n';
                     (void) WriteBlob(image,(size_t) (q-pixels),pixels);
                     q=pixels;
+                    added_newline=MagickTrue;
                   }
               }
             (void) memcpy((char *) q,buffer,extent);
             q+=(ptrdiff_t) extent;
             p++;
           }
+          if (added_newline == MagickFalse)
+            {
+              *q++='\n';
+              (void) WriteBlob(image,(size_t) (q-pixels),pixels);
+              q=pixels;
+            }
           if (image->previous == (Image *) NULL)
             {
               status=SetImageProgress(image,SaveImageTag,(MagickOffsetType) y,
