@@ -17,7 +17,7 @@
 %                                 April 2014                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -290,10 +290,11 @@ static inline Quantum ReadVIPSPixelNONE(Image *image,
         case VIPSBandFormatINT:
           return(ScaleLongToQuantum(ReadBlobLong(image)));
         case VIPSBandFormatFLOAT:
-          return((Quantum) ((float) QuantumRange*(ReadBlobFloat(image)/1.0)));
+          return((Quantum) ((MagickRealType) QuantumRange*
+            ((MagickRealType) ReadBlobFloat(image)/1.0)));
         case VIPSBandFormatDOUBLE:
-          return((Quantum) ((double) QuantumRange*(ReadBlobDouble(
-            image)/1.0)));
+          return((Quantum) ((MagickRealType) QuantumRange*
+            (ReadBlobDouble(image)/1.0)));
         default:
           return((Quantum) 0);
       }
@@ -522,7 +523,8 @@ static Image *ReadVIPSImage(const ImageInfo *image_info,
       SetImageProperty(image,"vips:metadata",metadata);
       metadata=(char *) RelinquishMagickMemory(metadata);
     }
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
   if (status == MagickFalse)
     return((Image *) NULL);
   return(image);
@@ -759,6 +761,7 @@ static MagickBooleanType WriteVIPSImage(const ImageInfo *image_info,
   metadata=GetImageProperty(image,"vips:metadata");
   if (metadata != (const char*) NULL)
     WriteBlobString(image,metadata);
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
   return(status);
 }
