@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -271,14 +271,14 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
               {
                 SetPixelGreen(chroma_pixels,ScaleShortToQuantum(((*p) << 8) |
                   *(p+1)));
-                p+=2;
+                p+=(ptrdiff_t) 2;
               }
             if (quantum == 1)
               SetPixelRed(q,ScaleCharToQuantum(*p++));
             else
               {
                 SetPixelRed(q,ScaleShortToQuantum(((*p) << 8) | *(p+1)));
-                p+=2;
+                p+=(ptrdiff_t) 2;
               }
             SetPixelGreen(q,0);
             SetPixelBlue(q,0);
@@ -291,14 +291,14 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
               {
                 SetPixelBlue(chroma_pixels,ScaleShortToQuantum(((*p) << 8) |
                   *(p+1)));
-                p+=2;
+                p+=(ptrdiff_t) 2;
               }
             if (quantum == 1)
               SetPixelRed(q,ScaleCharToQuantum(*p++));
             else
               {
                 SetPixelRed(q,ScaleShortToQuantum(((*p) << 8) | *(p+1)));
-                p+=2;
+                p+=(ptrdiff_t) 2;
               }
             chroma_pixels++;
             q++;
@@ -329,7 +329,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
             else
               {
                 SetPixelRed(q,ScaleShortToQuantum(((*p) << 8) | *(p+1)));
-                p+=2;
+                p+=(ptrdiff_t) 2;
               }
             SetPixelGreen(q,0);
             SetPixelBlue(q,0);
@@ -351,7 +351,8 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
     if (interlace == PartitionInterlace)
       {
-        (void) CloseBlob(image);
+        if (CloseBlob(image) == MagickFalse)
+          break;
         AppendImageFormat("U",image->filename);
         status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
         if (status == MagickFalse)
@@ -386,7 +387,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
             else
               {
                 SetPixelGreen(q,ScaleShortToQuantum(((*p) << 8) | *(p+1)));
-                p+=2;
+                p+=(ptrdiff_t) 2;
               }
             SetPixelBlue(q,0);
             q++;
@@ -396,7 +397,8 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
       if (interlace == PartitionInterlace)
         {
-          (void) CloseBlob(image);
+          if (CloseBlob(image) == MagickFalse)
+            break;
           AppendImageFormat("V",image->filename);
           status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
           if (status == MagickFalse)
@@ -428,7 +430,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
           else
             {
               SetPixelBlue(q,ScaleShortToQuantum(((*p) << 8) | *(p+1)));
-              p+=2;
+              p+=(ptrdiff_t) 2;
             }
           q++;
         }
@@ -504,7 +506,8 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
   } while (count != 0);
   scanline=(unsigned char *) RelinquishMagickMemory(scanline);
   InheritException(exception,&image->exception);
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
   if (status == MagickFalse)
     return(DestroyImageList(image));
   return(GetFirstImageInList(image));
@@ -795,7 +798,8 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
         */
         if (interlace == PartitionInterlace)
           {
-            (void) CloseBlob(image);
+            if (CloseBlob(image) == MagickFalse)
+              break;
             AppendImageFormat("U",image->filename);
             status=OpenBlob(image_info,image,WriteBinaryBlobMode,
               &image->exception);
@@ -829,7 +833,8 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
         */
         if (interlace == PartitionInterlace)
           {
-            (void) CloseBlob(image);
+            if (CloseBlob(image) == MagickFalse)
+              break;
             AppendImageFormat("V",image->filename);
             status=OpenBlob(image_info,image,WriteBinaryBlobMode,
               &image->exception);
@@ -869,6 +874,7 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
     if (status == MagickFalse)
       break;
   } while (image_info->adjoin != MagickFalse);
-  (void) CloseBlob(image);
-  return(MagickTrue);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
+  return(status);
 }
