@@ -90,6 +90,7 @@ static const MagicMapInfo
     { "8BIMTEXT", 0, MagicPattern("8BIM#") },
     { "8BIM", 0, MagicPattern("8BIM") },
     { "AVIF", 4, MagicPattern("ftypavif") },
+    { "AVIF", 4, MagicPattern("ftypavis") },
     { "BMP", 0, MagicPattern("BA") },
     { "BMP", 0, MagicPattern("BM") },
     { "BMP", 0, MagicPattern("CI") },
@@ -129,7 +130,13 @@ static const MagicMapInfo
     { "HDR", 0, MagicPattern("#?RGBE") },
     { "HEIC", 4, MagicPattern("ftypheic") },
     { "HEIC", 4, MagicPattern("ftypheix") },
+    { "HEIC", 4, MagicPattern("ftyphevc") },
+    { "HEIC", 4, MagicPattern("ftypheim") },
+    { "HEIC", 4, MagicPattern("ftypheis") },
+    { "HEIC", 4, MagicPattern("ftyphevm") },
+    { "HEIC", 4, MagicPattern("ftyphevs") },
     { "HEIC", 4, MagicPattern("ftypmif1") },
+    { "HEIC", 4, MagicPattern("ftypmsf1") },
     { "HPGL", 0, MagicPattern("IN;") },
     { "HTML", 1, MagicPattern("HTML") },
     { "HTML", 1, MagicPattern("html") },
