@@ -17,7 +17,7 @@
 %                                  July 1992                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -166,8 +166,8 @@ static MagickBooleanType CropToFitImage(Image **image,
   }
   geometry.x=CastDoubleToLong(ceil(min.x-0.5));
   geometry.y=CastDoubleToLong(ceil(min.y-0.5));
-  geometry.width=(size_t) floor(max.x-min.x+0.5);
-  geometry.height=(size_t) floor(max.y-min.y+0.5);
+  geometry.width=CastDoubleToUnsigned(max.x-min.x+0.5);
+  geometry.height=CastDoubleToUnsigned(max.y-min.y+0.5);
   page=(*image)->page;
   (void) ParseAbsoluteGeometry("0x0+0+0",&(*image)->page);
   crop_image=CropImage(*image,&geometry,exception);
@@ -542,23 +542,23 @@ static void GetImageBackgroundColor(Image *image,const ssize_t offset,
     {
       if ((x >= offset) && (x < ((ssize_t) image->columns-offset)))
         continue;
-      background.red+=QuantumScale*GetPixelRed(p);
-      background.green+=QuantumScale*GetPixelGreen(p);
-      background.blue+=QuantumScale*GetPixelBlue(p);
-      background.opacity+=QuantumScale*GetPixelOpacity(p);
+      background.red+=QuantumScale*(MagickRealType) GetPixelRed(p);
+      background.green+=QuantumScale*(MagickRealType) GetPixelGreen(p);
+      background.blue+=QuantumScale*(MagickRealType) GetPixelBlue(p);
+      background.opacity+=QuantumScale*(MagickRealType) GetPixelOpacity(p);
       count++;
       p++;
     }
   }
   image_view=DestroyCacheView(image_view);
   image->background_color.red=ClampToQuantum((MagickRealType) QuantumRange*
-    background.red/count);
+    (MagickRealType) background.red/count);
   image->background_color.green=ClampToQuantum((MagickRealType) QuantumRange*
-    background.green/count);
+    (MagickRealType) background.green/count);
   image->background_color.blue=ClampToQuantum((MagickRealType) QuantumRange*
-    background.blue/count);
+    (MagickRealType) background.blue/count);
   image->background_color.opacity=ClampToQuantum((MagickRealType) QuantumRange*
-    background.opacity/count);
+    (MagickRealType) background.opacity/count);
 }
 
 MagickExport Image *DeskewImage(const Image *image,const double threshold,
@@ -904,7 +904,7 @@ MagickExport Image *IntegralRotateImage(const Image *image,size_t rotations,
       */
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
       #pragma omp parallel for schedule(static) shared(status) \
-        magick_number_threads(image,rotate_image,image->rows,1)
+        magick_number_threads(image,rotate_image,image->rows,2)
 #endif
       for (y=0; y < (ssize_t) image->rows; y++)
       {
@@ -939,7 +939,7 @@ MagickExport Image *IntegralRotateImage(const Image *image,size_t rotations,
           }
         indexes=GetCacheViewVirtualIndexQueue(image_view);
         rotate_indexes=GetCacheViewAuthenticIndexQueue(rotate_view);
-        q+=image->columns;
+        q+=(ptrdiff_t) image->columns;
         for (x=0; x < (ssize_t) image->columns; x++)
           *--q=(*p++);
         if ((indexes != (IndexPacket *) NULL) &&
@@ -986,7 +986,7 @@ MagickExport Image *IntegralRotateImage(const Image *image,size_t rotations,
       tile_width=image->columns;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
       #pragma omp parallel for schedule(static) shared(status) \
-        magick_number_threads(image,rotate_image,image->rows/tile_height,1)
+        magick_number_threads(image,rotate_image,image->rows/tile_height,2)
 #endif
       for (tile_y=0; tile_y < (ssize_t) image->rows; tile_y+=(ssize_t) tile_height)
       {
@@ -1226,7 +1226,7 @@ static MagickBooleanType XShearImage(Image *image,const MagickRealType degrees,
         continue;
       }
     indexes=GetCacheViewAuthenticIndexQueue(image_view);
-    p+=x_offset;
+    p+=(ptrdiff_t) x_offset;
     indexes+=x_offset;
     displacement=degrees*(MagickRealType) (y-height/2.0);
     if (displacement == 0.0)
@@ -1282,7 +1282,7 @@ static MagickBooleanType XShearImage(Image *image,const MagickRealType degrees,
         /*
           Transfer pixels right-to-left.
         */
-        p+=width;
+        p+=(ptrdiff_t) width;
         indexes+=width;
         q=p+step;
         shear_indexes=indexes+step;
@@ -1448,7 +1448,7 @@ static MagickBooleanType YShearImage(Image *image,const MagickRealType degrees,
         continue;
       }
     indexes=GetCacheViewAuthenticIndexQueue(image_view);
-    p+=y_offset;
+    p+=(ptrdiff_t) y_offset;
     indexes+=y_offset;
     displacement=degrees*(MagickRealType) (x-width/2.0);
     if (displacement == 0.0)
@@ -1504,7 +1504,7 @@ static MagickBooleanType YShearImage(Image *image,const MagickRealType degrees,
         /*
           Transfer pixels bottom-to-top.
         */
-        p+=height;
+        p+=(ptrdiff_t) height;
         indexes+=height;
         q=p+step;
         shear_indexes=indexes+step;
@@ -1787,9 +1787,9 @@ MagickExport Image *ShearRotateImage(const Image *image,const double degrees,
   */
   width=integral_image->columns;
   height=integral_image->rows;
-  bounds.width=(size_t) floor(fabs((double) height*shear.x)+width+0.5);
-  bounds.height=(size_t) floor(fabs((double) bounds.width*shear.y)+height+0.5);
-  shear_width=(size_t) floor(fabs((double) bounds.height*shear.x)+
+  bounds.width=CastDoubleToUnsigned(fabs((double) height*shear.x)+width+0.5);
+  bounds.height=CastDoubleToUnsigned(fabs((double) bounds.width*shear.y)+height+0.5);
+  shear_width=CastDoubleToUnsigned(fabs((double) bounds.height*shear.x)+
     bounds.width+0.5);
   bounds.x=CastDoubleToLong(floor((double) ((shear_width > bounds.width) ?
     width : bounds.width-shear_width+2)/2.0+0.5));
