@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
-  You may not use this file except in compliance with the License.
+  You may not use this file except in compliance with the License.  You may
   obtain a copy of the License at
   
-    http://www.imagemagick.org/script/license.php
+    https://imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,13 +15,21 @@
 
   MagickCore image threshold methods.
 */
-#ifndef _MAGICKCORE_THRESHOLD_H
-#define _MAGICKCORE_THRESHOLD_H
+#ifndef MAGICKCORE_THRESHOLD_H
+#define MAGICKCORE_THRESHOLD_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
 
+typedef enum
+{
+  UndefinedThresholdMethod,
+  KapurThresholdMethod,
+  OTSUThresholdMethod,
+  TriangleThresholdMethod
+} AutoThresholdMethod;
+
 typedef struct _ThresholdMap
   ThresholdMap;
 
@@ -34,6 +42,7 @@ extern MagickExport ThresholdMap
   *GetThresholdMap(const char *,ExceptionInfo *);
 
 extern MagickExport MagickBooleanType
+  AutoThresholdImage(Image *,const AutoThresholdMethod,ExceptionInfo *),
   BilevelImage(Image *,const double),
   BilevelImageChannel(Image *,const ChannelType,const double),
   BlackThresholdImage(Image *,const char *),
