@@ -17,7 +17,7 @@
 %                              July 1992                                      %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -80,7 +80,6 @@ static int StreamMain(int argc,char **argv)
   image_info=DestroyImageInfo(image_info);
   exception=DestroyExceptionInfo(exception);
   MagickWandTerminus();
-  MagickCoreTerminus();
   return(status != MagickFalse ? 0 : 1);
 }
 
@@ -90,17 +89,24 @@ int main(int argc,char **argv)
   return(StreamMain(argc,argv));
 }
 #else
+static LONG WINAPI NTUncaughtException(EXCEPTION_POINTERS *info)
+{ 
+  magick_unreferenced(info);
+  AsynchronousResourceComponentTerminus();
+  return(EXCEPTION_CONTINUE_SEARCH);
+}
+
 int wmain(int argc,wchar_t *argv[])
 {
   char
     **utf8;
 
   int
+    i,
     status;
 
-  int
-    i;
-
+  SetUnhandledExceptionFilter(NTUncaughtException);
+  SetConsoleOutputCP(CP_UTF8);
   utf8=NTArgvToUTF8(argc,argv);
   status=StreamMain(argc,utf8);
   for (i=0; i < argc; i++)
