@@ -44,6 +44,7 @@
 #include "wand/studio.h"
 #include "wand/MagickWand.h"
 #include "wand/mogrify-private.h"
+#include "magick/compare-private.h"
 #include "magick/image-private.h"
 #include "magick/string-private.h"
 
@@ -196,8 +197,11 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
   int argc,char **argv,char **metadata,ExceptionInfo *exception)
 {
 #define CompareEpsilon  (1.0e-06)
+#define CompareConstantColorException \
+  "search metric is unreliable for constant-color images"
+#define CompareEqualSizedException \
+  "subimage search metric is unreliable for equal-sized images"
 #define DefaultDissimilarityThreshold  (1.0/MagickPI)
-#define DefaultSimilarityThreshold  (-1.0)
 #define DestroyCompare() \
 { \
   if (similarity_image != (Image *) NULL) \
@@ -225,6 +229,9 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
   return(MagickFalse); \
 }
 
+  ChannelType
+    channels = DefaultChannels;
+
   char
     *filename,
     *option;
@@ -232,14 +239,12 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
   const char
     *format;
 
-  ChannelType
-    channels;
-
   double
-    dissimilarity_threshold,
-    distortion,
-    similarity_metric,
-    similarity_threshold;
+    dissimilarity_threshold = DefaultDissimilarityThreshold,
+    distortion = 0.0,
+    scale = (double) QuantumRange,
+    similarity_metric = 0.0,
+    similarity_threshold = DefaultSimilarityThreshold;
 
   Image
     *difference_image,
@@ -264,7 +269,7 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
     status;
 
   MetricType
-    metric;
+    metric = UndefinedErrorMetric;
 
   RectangleInfo
     offset;
@@ -302,16 +307,11 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
       return(MagickFalse);
     }
   restore_info=image_info;
-  channels=DefaultChannels;
   difference_image=NewImageList();
   similarity_image=NewImageList();
-  dissimilarity_threshold=DefaultDissimilarityThreshold;
-  similarity_threshold=DefaultSimilarityThreshold;
-  distortion=0.0;
   format=(char *) NULL;
   j=1;
   k=0;
-  metric=UndefinedErrorMetric;
   NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
@@ -1168,13 +1168,13 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
       (void) SetImageArtifact(image,"compare:similarity-threshold",artifact);
       similarity_image=SimilarityMetricImage(image,reconstruct_image,metric,
         &offset,&similarity_metric,exception);
-      if (similarity_metric > dissimilarity_threshold)
+      if (similarity_metric >= dissimilarity_threshold)
         (void) ThrowMagickException(exception,GetMagickModule(),ImageWarning,
           "ImagesTooDissimilar","`%s'",image->filename);
     }
   if (similarity_image == (Image *) NULL)
-    difference_image=CompareImageChannels(image,reconstruct_image,channels,
-      metric,&distortion,exception);
+    difference_image=CompareImageChannels(image,reconstruct_image,channels,metric,
+      &distortion,exception);
   else
     {
       Image
@@ -1185,8 +1185,8 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
       */
       composite_image=CloneImage(image,0,0,MagickTrue,exception);
       if (composite_image == (Image *) NULL)
-        difference_image=CompareImageChannels(image,reconstruct_image,
-          channels,metric,&distortion,exception);
+        difference_image=CompareImageChannels(image,reconstruct_image,channels,
+          metric,&distortion,exception);
       else
         {
           Image
@@ -1197,8 +1197,8 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
 
           (void) CompositeImage(composite_image,CopyCompositeOp,
             reconstruct_image,offset.x,offset.y);
-          difference_image=CompareImageChannels(image,composite_image,
-            channels,metric,&distortion,exception);
+          difference_image=CompareImageChannels(image,composite_image,channels,
+            metric,&distortion,exception);
           if (difference_image != (Image *) NULL)
             {
               difference_image->page.x=offset.x;
@@ -1215,11 +1215,13 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
               Image
                 *sans_image;
 
-              sans_image=CompareImageChannels(distort_image,reconstruct_image,
-                channels,metric,&distortion,exception);
-              distort_image=DestroyImage(distort_image);
+              (void) SetImageArtifact(distort_image,"compare:virtual-pixels",
+                "false");
+              sans_image=CompareImages(distort_image,reconstruct_image,metric,
+                &distortion,exception);
               if (sans_image != (Image *) NULL)
                 sans_image=DestroyImage(sans_image);
+              distort_image=DestroyImage(distort_image);
             }
         }
       if (difference_image != (Image *) NULL)
@@ -1228,23 +1230,73 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
           similarity_image=(Image *) NULL;
         }
     }
-  if (fabs(distortion) > CompareEpsilon)
-    similar=MagickFalse;
   switch (metric)
   {
+    case AbsoluteErrorMetric:
+    {
+      size_t
+        columns,
+        rows;
+
+      SetImageCompareBounds(image,reconstruct_image,&columns,&rows);
+      scale=(double) columns*rows;
+      break;
+    }
     case NormalizedCrossCorrelationErrorMetric:
     {
-      distortion=1.0-distortion;
-      similarity_metric=1.0-similarity_metric;
+      double
+        maxima = 0.0,
+        minima = 0.0;
+
+      (void) GetImageRange(reconstruct_image,&minima,&maxima,exception);
+      if (fabs(maxima-minima) < MagickEpsilon)
+        (void) ThrowMagickException(exception,GetMagickModule(),ImageWarning,
+          CompareConstantColorException,"(%s)",CommandOptionToMnemonic(
+          MagickMetricOptions,(ssize_t) metric));
+      break;
+    } 
+    case PeakAbsoluteErrorMetric:
+    {
+      if ((subimage_search != MagickFalse) &&
+          (image->columns == reconstruct_image->columns) &&
+          (image->rows == reconstruct_image->rows))
+        (void) ThrowMagickException(exception,GetMagickModule(),ImageWarning,
+          CompareEqualSizedException,"(%s)",CommandOptionToMnemonic(
+          MagickMetricOptions,(ssize_t) metric));
+      break;
+    }
+    case PerceptualHashErrorMetric:
+    {
+      if (subimage_search == MagickFalse)
+        {
+          double
+            maxima = 0.0,
+            minima = 0.0;
+
+          (void) GetImageRange(reconstruct_image,&minima,&maxima,exception);
+          if (fabs(maxima-minima) < MagickEpsilon)
+            (void) ThrowMagickException(exception,GetMagickModule(),
+              ImageWarning,CompareConstantColorException,"(%s)",
+              CommandOptionToMnemonic(MagickMetricOptions,(ssize_t) metric));
+        }
+      if ((subimage_search != MagickFalse) &&
+          (image->columns == reconstruct_image->columns) &&
+          (image->rows == reconstruct_image->rows))
+        (void) ThrowMagickException(exception,GetMagickModule(),ImageWarning,
+          CompareEqualSizedException,"(%s)",CommandOptionToMnemonic(
+          MagickMetricOptions,(ssize_t) metric));
+      break;
     }
     case PeakSignalToNoiseRatioMetric:
     {
-      distortion=fabs(distortion);
-      similarity_metric=fabs(similarity_metric);
+      scale=MagickSafePSNRRecipicol(10.0);
+      break;
     }
     default:
       break;
   }
+  if (fabs(distortion) > CompareEpsilon)
+    similar=MagickFalse;
   if (difference_image == (Image *) NULL)
     status=0;
   else
@@ -1258,36 +1310,30 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
         {
           switch (metric)
           {
-            case FuzzErrorMetric:
-            case MeanAbsoluteErrorMetric:
-            case MeanSquaredErrorMetric:
-            case PeakAbsoluteErrorMetric:
-            case RootMeanSquaredErrorMetric:
             case AbsoluteErrorMetric:
-            case NormalizedCrossCorrelationErrorMetric:
-            case PerceptualHashErrorMetric:
             {
               (void) FormatLocaleFile(stderr,"%.*g (%.*g)",GetMagickPrecision(),
-                (double) QuantumRange*distortion,GetMagickPrecision(),
-                distortion);
-              break;
-            }
-            case PeakSignalToNoiseRatioMetric:
-            {
-              (void) FormatLocaleFile(stderr,"%.*g (%.*g)",GetMagickPrecision(),
-                48.1647*distortion,GetMagickPrecision(),distortion);
+                ceil(scale*distortion),GetMagickPrecision(),distortion);
               break;
             }
             case MeanErrorPerPixelMetric:
             {
-              (void) FormatLocaleFile(stderr,"%.*g (%.*g, %.*g)",
-                GetMagickPrecision(),distortion,
-                GetMagickPrecision(),image->error.normalized_mean_error,
-                GetMagickPrecision(),image->error.normalized_maximum_error);
+              if (subimage_search == MagickFalse)
+                {
+                  (void) FormatLocaleFile(stderr,"%.*g (%.*g, %.*g)",
+                    GetMagickPrecision(),scale*distortion,
+                    GetMagickPrecision(),distortion,GetMagickPrecision(),
+                    image->error.normalized_maximum_error);
+                  break;
+                }
+              magick_fallthrough;
+            }
+            default:
+            {
+              (void) FormatLocaleFile(stderr,"%.*g (%.*g)",GetMagickPrecision(),
+                scale*distortion,GetMagickPrecision(),distortion);
               break;
             }
-            case UndefinedErrorMetric:
-              break;
           }
           if (subimage_search != MagickFalse)
             (void) FormatLocaleFile(stderr," @ %.20g,%.20g [%.*g]",
@@ -1315,6 +1361,7 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
             case MeanSquaredErrorMetric:
             case PeakAbsoluteErrorMetric:
             case RootMeanSquaredErrorMetric:
+            case UndefinedErrorMetric:
             {
               switch (image->colorspace)
               {
@@ -1322,20 +1369,17 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
                 default:
                 {
                   (void) FormatLocaleFile(stderr,"    red: %.*g (%.*g)\n",
-                    GetMagickPrecision(),(double) QuantumRange*
-                    channel_distortion[RedChannel],GetMagickPrecision(),
-                    channel_distortion[RedChannel]);
+                    GetMagickPrecision(),scale*channel_distortion[RedChannel],
+                    GetMagickPrecision(),channel_distortion[RedChannel]);
                   (void) FormatLocaleFile(stderr,"    green: %.*g (%.*g)\n",
-                    GetMagickPrecision(),(double) QuantumRange*
-                    channel_distortion[GreenChannel],GetMagickPrecision(),
-                    channel_distortion[GreenChannel]);
+                    GetMagickPrecision(),scale*channel_distortion[GreenChannel],
+                    GetMagickPrecision(),channel_distortion[GreenChannel]);
                   (void) FormatLocaleFile(stderr,"    blue: %.*g (%.*g)\n",
-                    GetMagickPrecision(),(double) QuantumRange*
-                    channel_distortion[BlueChannel],GetMagickPrecision(),
-                    channel_distortion[BlueChannel]);
+                    GetMagickPrecision(),scale*channel_distortion[BlueChannel],
+                    GetMagickPrecision(),channel_distortion[BlueChannel]);
                   if (image->matte != MagickFalse)
                     (void) FormatLocaleFile(stderr,"    alpha: %.*g (%.*g)\n",
-                      GetMagickPrecision(),(double) QuantumRange*
+                      GetMagickPrecision(),scale*
                       channel_distortion[OpacityChannel],GetMagickPrecision(),
                       channel_distortion[OpacityChannel]);
                   break;
@@ -1343,24 +1387,22 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
                 case CMYKColorspace:
                 {
                   (void) FormatLocaleFile(stderr,"    cyan: %.*g (%.*g)\n",
-                    GetMagickPrecision(),(double) QuantumRange*
-                    channel_distortion[CyanChannel],GetMagickPrecision(),
-                    channel_distortion[CyanChannel]);
+                    GetMagickPrecision(),scale*channel_distortion[CyanChannel],
+                    GetMagickPrecision(),channel_distortion[CyanChannel]);
                   (void) FormatLocaleFile(stderr,"    magenta: %.*g (%.*g)\n",
-                    GetMagickPrecision(),(double) QuantumRange*
+                    GetMagickPrecision(),scale*
                     channel_distortion[MagentaChannel],GetMagickPrecision(),
                     channel_distortion[MagentaChannel]);
                   (void) FormatLocaleFile(stderr,"    yellow: %.*g (%.*g)\n",
-                    GetMagickPrecision(),(double) QuantumRange*
+                    GetMagickPrecision(),scale*
                     channel_distortion[YellowChannel],GetMagickPrecision(),
                     channel_distortion[YellowChannel]);
                   (void) FormatLocaleFile(stderr,"    black: %.*g (%.*g)\n",
-                    GetMagickPrecision(),(double) QuantumRange*
-                    channel_distortion[BlackChannel],GetMagickPrecision(),
-                    channel_distortion[BlackChannel]);
+                    GetMagickPrecision(),scale*channel_distortion[BlackChannel],
+                    GetMagickPrecision(),channel_distortion[BlackChannel]);
                   if (image->matte != MagickFalse)
                     (void) FormatLocaleFile(stderr,"    alpha: %.*g (%.*g)\n",
-                      GetMagickPrecision(),(double) QuantumRange*
+                      GetMagickPrecision(),scale*
                       channel_distortion[OpacityChannel],GetMagickPrecision(),
                       channel_distortion[OpacityChannel]);
                   break;
@@ -1369,19 +1411,18 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
                 case GRAYColorspace:
                 {
                   (void) FormatLocaleFile(stderr,"    gray: %.*g (%.*g)\n",
-                    GetMagickPrecision(),(double) QuantumRange*
-                    channel_distortion[GrayChannel],GetMagickPrecision(),
-                    channel_distortion[GrayChannel]);
+                    GetMagickPrecision(),scale*channel_distortion[GrayChannel],
+                    GetMagickPrecision(),channel_distortion[GrayChannel]);
                   if (image->matte != MagickFalse)
                     (void) FormatLocaleFile(stderr,"    alpha: %.*g (%.*g)\n",
-                      GetMagickPrecision(),(double) QuantumRange*
+                      GetMagickPrecision(),scale*
                       channel_distortion[OpacityChannel],GetMagickPrecision(),
                       channel_distortion[OpacityChannel]);
                   break;
                 }
               }
               (void) FormatLocaleFile(stderr,"    all: %.*g (%.*g)\n",
-                GetMagickPrecision(),(double) QuantumRange*
+                GetMagickPrecision(),scale*
                 channel_distortion[CompositeChannels],GetMagickPrecision(),
                 channel_distortion[CompositeChannels]);
               break;
@@ -1441,12 +1482,10 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
             {
               (void) FormatLocaleFile(stderr,"    %.*g (%.*g, %.*g)\n",
                 GetMagickPrecision(),channel_distortion[CompositeChannels],
-                GetMagickPrecision(),image->error.normalized_mean_error,
+                GetMagickPrecision(),channel_distortion[CompositeChannels],
                 GetMagickPrecision(),image->error.normalized_maximum_error);
               break;
             }
-            case UndefinedErrorMetric:
-              break;
           }
           channel_distortion=(double *) RelinquishMagickMemory(
             channel_distortion);
@@ -1457,6 +1496,11 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
                 difference_image->page.y);
               (void) FormatLocaleFile(stderr,"    Similarity metric: %.*g\n",
                 GetMagickPrecision(),similarity_metric);
+              (void) FormatLocaleFile(stderr,"   Similarity threshold: %*g\n",
+                GetMagickPrecision(),similarity_threshold);
+              (void) FormatLocaleFile(stderr,
+                "   Dissimilarity threshold: %*g\n",GetMagickPrecision(),
+                dissimilarity_threshold);
             }
         }
       (void) ResetImagePage(difference_image,"0x0+0+0");
